@@ -22,7 +22,7 @@
 #       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-VERSION=4.0.15
+VERSION=4.2.10
 
 usage() # $1 = exit status
 {
@@ -35,7 +35,8 @@ usage() # $1 = exit status
 }
 
 split() {
-    local ifs=$IFS
+    local ifs
+    ifs=$IFS
     IFS=:
     set -- $1
     echo $*
@@ -337,13 +338,13 @@ cd manpages
 for f in *.5; do
     gzip -c $f > $f.gz
     run_install -D -m 644 $f.gz ${PREFIX}/usr/share/man/man5/$f.gz
-    echo "Man page $f.gz installed to /usr/share/man/man5/$f.gz"
+    echo "Man page $f.gz installed to ${PREFIX}/usr/share/man/man5/$f.gz"
 done
 
 for f in *.8; do
     gzip -c $f > $f.gz
     run_install -D -m 644 $f.gz ${PREFIX}/usr/share/man/man8/$f.gz
-    echo "Man page $f.gz installed to /usr/share/man/man8/$f.gz"
+    echo "Man page $f.gz installed to ${PREFIX}/usr/share/man/man8/$f.gz"
 done
 
 cd ..
